@@ -1,21 +1,19 @@
-/***************************************************************************
- *   Copyright (C) 2008,2009,2011 by Volker Lanz <vl@fidra.de>             *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
- ***************************************************************************/
+/*************************************************************************
+ *  Copyright (C) 2008,2009,2011 by Volker Lanz <vl@fidra.de>            *
+ *                                                                       *
+ *  This program is free software; you can redistribute it and/or        *
+ *  modify it under the terms of the GNU General Public License as       *
+ *  published by the Free Software Foundation; either version 3 of       *
+ *  the License, or (at your option) any later version.                  *
+ *                                                                       *
+ *  This program is distributed in the hope that it will be useful,      *
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of       *
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
+ *  GNU General Public License for more details.                         *
+ *                                                                       *
+ *  You should have received a copy of the GNU General Public License    *
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
+ *************************************************************************/
 
 #include "fs/fat16.h"
 
@@ -25,8 +23,7 @@
 
 #include "fatlabel/fatlabel.h"
 
-#include <kdebug.h>
-#include <klocale.h>
+#include <KLocalizedString>
 
 #include <QString>
 #include <QStringList>
@@ -56,14 +53,14 @@ namespace FS
 
 	void fat16::init()
 	{
-		m_Create = findExternal("mkfs.msdos") ? cmdSupportFileSystem : cmdSupportNone;
-		m_GetUsed = m_Check = findExternal("fsck.msdos", QStringList(), 2) ? cmdSupportFileSystem : cmdSupportNone;
+		m_Create = findExternal(QStringLiteral("mkfs.msdos")) ? cmdSupportFileSystem : cmdSupportNone;
+		m_GetUsed = m_Check = findExternal(QStringLiteral("fsck.msdos"), QStringList(), 2) ? cmdSupportFileSystem : cmdSupportNone;
 		m_GetLabel = cmdSupportCore;
 		m_SetLabel = cmdSupportFileSystem;
 		m_Move = cmdSupportCore;
 		m_Copy = cmdSupportCore;
 		m_Backup = cmdSupportCore;
-		m_UpdateUUID = findExternal("dd") ? cmdSupportFileSystem : cmdSupportNone;
+		m_UpdateUUID = findExternal(QStringLiteral("dd")) ? cmdSupportFileSystem : cmdSupportNone;
 		m_GetUUID = cmdSupportCore;
 	}
 
@@ -87,7 +84,7 @@ namespace FS
 	FileSystem::SupportTool fat16::supportToolName() const
 	{
 		// also, dd for updating the UUID, but let's assume it's there ;-)
-		return SupportTool("dosfstools", KUrl("http://www.daniel-baumann.ch/software/dosfstools/"));
+		return SupportTool(QStringLiteral("dosfstools"), QUrl(QStringLiteral("http://www.daniel-baumann.ch/software/dosfstools/")));
 	}
 
 
@@ -108,19 +105,19 @@ namespace FS
 
 	qint64 fat16::readUsedCapacity(const QString& deviceNode) const
 	{
-		ExternalCommand cmd("fsck.msdos", QStringList() << "-n" << "-v" << deviceNode);
+		ExternalCommand cmd(QStringLiteral("fsck.msdos"), QStringList() << QStringLiteral("-n") << QStringLiteral("-v") << deviceNode);
 
 		if (cmd.run())
 		{
 			qint64 usedClusters = -1;
-			QRegExp rxClusters("files, (\\d+)/\\d+ ");
+			QRegExp rxClusters(QStringLiteral("files, (\\d+)/\\d+ "));
 
 			if (rxClusters.indexIn(cmd.output()) != -1)
 				usedClusters = rxClusters.cap(1).toLongLong();
 
 			qint64 clusterSize = -1;
 
-			QRegExp rxClusterSize("(\\d+) bytes per cluster");
+			QRegExp rxClusterSize(QStringLiteral("(\\d+) bytes per cluster"));
 
 			if (rxClusterSize.indexIn(cmd.output()) != -1)
 				clusterSize = rxClusterSize.cap(1).toLongLong();
@@ -134,20 +131,20 @@ namespace FS
 
 	bool fat16::writeLabel(Report& report, const QString& deviceNode, const QString& newLabel)
 	{
-		report.line() << i18nc("@info/plain", "Setting label for partition <filename>%1</filename> to %2", deviceNode, newLabel);
+		report.line() << xi18nc("@info/plain", "Setting label for partition <filename>%1</filename> to %2", deviceNode, newLabel);
 
-		return fatlabel_set_label(deviceNode.toLocal8Bit(), newLabel.toLocal8Bit()) == 0;
+		return fatlabel_set_label(deviceNode.toLocal8Bit().constData(), newLabel.toLocal8Bit().constData()) == 0;
 	}
 
 	bool fat16::check(Report& report, const QString& deviceNode) const
 	{
-		ExternalCommand cmd(report, "fsck.msdos", QStringList() << "-a" << "-w" << "-v" << deviceNode);
+		ExternalCommand cmd(report, QStringLiteral("fsck.msdos"), QStringList() << QStringLiteral("-a") << QStringLiteral("-w") << QStringLiteral("-v") << deviceNode);
 		return cmd.run(-1) && cmd.exitCode() == 0;
 	}
 
 	bool fat16::create(Report& report, const QString& deviceNode) const
 	{
-		ExternalCommand cmd(report, "mkfs.msdos", QStringList() << "-F16" << "-I" << "-v" << deviceNode);
+		ExternalCommand cmd(report, QStringLiteral("mkfs.msdos"), QStringList() << QStringLiteral("-F16") << QStringLiteral("-I") << QStringLiteral("-v") << deviceNode);
 		return cmd.run(-1) && cmd.exitCode() == 0;
 	}
 
@@ -159,7 +156,7 @@ namespace FS
 		for (quint32 i = 0; i < sizeof(uuid); i++, t >>= 8)
 			uuid[i] = t & 0xff;
 
-		ExternalCommand cmd(report, "dd", QStringList() << "of=" + deviceNode << "bs=1" << "count=4" << "seek=39");
+		ExternalCommand cmd(report, QStringLiteral("dd"), QStringList() << QStringLiteral("of=") + deviceNode << QStringLiteral("bs=1") << QStringLiteral("count=4") << QStringLiteral("seek=39"));
 
 		if (!cmd.start())
 			return false;
