@@ -1,21 +1,19 @@
-/***************************************************************************
- *   Copyright (C) 2008,2011 by Volker Lanz <vl@fidra.de>                  *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
- ***************************************************************************/
+/*************************************************************************
+ *  Copyright (C) 2008,2011 by Volker Lanz <vl@fidra.de>                 *
+ *                                                                       *
+ *  This program is free software; you can redistribute it and/or        *
+ *  modify it under the terms of the GNU General Public License as       *
+ *  published by the Free Software Foundation; either version 3 of       *
+ *  the License, or (at your option) any later version.                  *
+ *                                                                       *
+ *  This program is distributed in the hope that it will be useful,      *
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of       *
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
+ *  GNU General Public License for more details.                         *
+ *                                                                       *
+ *  You should have received a copy of the GNU General Public License    *
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
+ *************************************************************************/
 
 #include "fs/hfsplus.h"
 
@@ -40,7 +38,7 @@ namespace FS
 
 	void hfsplus::init()
 	{
-		m_Check = findExternal("hpfsck") ? cmdSupportFileSystem : cmdSupportNone;
+		m_Check = findExternal(QStringLiteral("hpfsck")) ? cmdSupportFileSystem : cmdSupportNone;
 		m_Copy = (m_Check != cmdSupportNone) ? cmdSupportCore : cmdSupportNone;
 		m_Move = (m_Check != cmdSupportNone) ? cmdSupportCore : cmdSupportNone;
 		m_Backup = cmdSupportCore;
@@ -65,7 +63,7 @@ namespace FS
 
 	FileSystem::SupportTool hfsplus::supportToolName() const
 	{
-		return SupportTool("hfsplus", KUrl());
+		return SupportTool(QStringLiteral("hfsplus"), QUrl());
 	}
 
 	qint64 hfsplus::maxCapacity() const
@@ -80,7 +78,7 @@ namespace FS
 
 	bool hfsplus::check(Report& report, const QString& deviceNode) const
 	{
-		ExternalCommand cmd(report, "hpfsck", QStringList() << "-v" << deviceNode);
+		ExternalCommand cmd(report, QStringLiteral("hpfsck"), QStringList() << QStringLiteral("-v") << deviceNode);
 		return cmd.run(-1) && cmd.exitCode() == 0;
 	}
 }
