@@ -1,21 +1,19 @@
-/***************************************************************************
- *   Copyright (C) 2009,2010 by Volker Lanz <vl@fidra.de>                  *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
- ***************************************************************************/
+/*************************************************************************
+ *  Copyright (C) 2009, 2010 by Volker Lanz <vl@fidra.de>                *
+ *                                                                       *
+ *  This program is free software; you can redistribute it and/or        *
+ *  modify it under the terms of the GNU General Public License as       *
+ *  published by the Free Software Foundation; either version 3 of       *
+ *  the License, or (at your option) any later version.                  *
+ *                                                                       *
+ *  This program is distributed in the hope that it will be useful,      *
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of       *
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
+ *  GNU General Public License for more details.                         *
+ *                                                                       *
+ *  You should have received a copy of the GNU General Public License    *
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
+ *************************************************************************/
 
 #if !defined(EDITMOUNTPOINTDIALOGWIDGET__H)
 
@@ -28,13 +26,11 @@
 
 class Partition;
 
-class KPushButton;
-class KLineEdit;
-class KComboBox;
-
 class QWidget;
 class QSpinBox;
 class QCheckBox;
+class QLineEdit;
+class QPushButton;
 class QStringList;
 class QFile;
 
@@ -49,9 +45,9 @@ class EditMountPointDialogWidget : public QWidget, public Ui::EditMountPointDial
 		~EditMountPointDialogWidget();
 
 	public:
-		KPushButton& buttonMore() { return *m_ButtonMore; }
+		QPushButton& buttonMore() { return *m_ButtonMore; }
 		QLabel& labelName() { return *m_LabelNameValue; }
-		KLineEdit& editPath() { return *m_EditPath; }
+		QLineEdit& editPath() { return *m_EditPath; }
 		QSpinBox& spinDumpFreq() { return *m_SpinDumpFreq; }
 		QSpinBox& spinPassNumber() { return *m_SpinPassNumber; }
 		QLabel& labelType() { return *m_LabelTypeValue; }
@@ -63,7 +59,7 @@ class EditMountPointDialogWidget : public QWidget, public Ui::EditMountPointDial
 		bool acceptChanges();
 		bool writeMountpoints(const QString& filename);
 
-	protected slots:
+	protected Q_SLOTS:
 		void on_m_ButtonSelect_clicked(bool);
 		void on_m_ButtonMore_clicked(bool);
 
