@@ -1,21 +1,19 @@
-/***************************************************************************
- *   Copyright (C) 2008,2010 by Volker Lanz <vl@fidra.de>                  *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
- ***************************************************************************/
+/*************************************************************************
+ *  Copyright (C) 2008, 2010 by Volker Lanz <vl@fidra.de>                *
+ *                                                                       *
+ *  This program is free software; you can redistribute it and/or        *
+ *  modify it under the terms of the GNU General Public License as       *
+ *  published by the Free Software Foundation; either version 3 of       *
+ *  the License, or (at your option) any later version.                  *
+ *                                                                       *
+ *  This program is distributed in the hope that it will be useful,      *
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of       *
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
+ *  GNU General Public License for more details.                         *
+ *                                                                       *
+ *  You should have received a copy of the GNU General Public License    *
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
+ *************************************************************************/
 
 #include "gui/newdialog.h"
 #include "gui/sizedialogwidget.h"
@@ -30,10 +28,13 @@
 #include "util/capacity.h"
 #include "util/helpers.h"
 
-#include <kdebug.h>
-
+#include <QFontDatabase>
 #include <QtAlgorithms>
 
+#include <KConfigGroup>
+#include <KLocalizedString>
+#include <KSharedConfig>
+
 /** Creates a NewDialog
 	@param parent the parent widget
 	@param device the Device on which a new Partition is to be created
@@ -44,19 +45,20 @@ NewDialog::NewDialog(QWidget* parent, Device& device, Partition& unallocatedPart
 	SizeDialogBase(parent, device, unallocatedPartition, unallocatedPartition.firstSector(), unallocatedPartition.lastSector()),
 	m_PartitionRoles(r)
 {
-	setCaption(i18nc("@title:window", "Create a new partition"));
+	setWindowTitle(i18nc("@title:window", "Create a new partition"));
 
 	setupDialog();
 	setupConstraints();
 	setupConnections();
 
-	restoreDialogSize(KConfigGroup(KGlobal::config(), "newDialog"));
+	KConfigGroup kcg(KSharedConfig::openConfig(), "newDialog");
+	restoreGeometry(kcg.readEntry<QByteArray>("Geometry", QByteArray()));
 }
 
 NewDialog::~NewDialog()
 {
-	KConfigGroup kcg(KGlobal::config(), "newDialog");
-	saveDialogSize(kcg);
+	KConfigGroup kcg(KSharedConfig::openConfig(), "newDialog");
+	kcg.writeEntry("Geometry", saveGeometry());
 }
 
 void NewDialog::setupDialog()
@@ -111,7 +113,7 @@ void NewDialog::accept()
 		partition().setFileSystem(FileSystemFactory::create(FileSystem::Extended, partition().firstSector(), partition().lastSector()));
 	}
 
-	KDialog::accept();
+	QDialog::accept();
 }
 
 void NewDialog::onRoleChanged(bool)
@@ -156,7 +158,7 @@ void NewDialog::onFilesystemChanged(int idx)
 
 	setupConstraints();
 
-	const FileSystem* fs = FileSystemFactory::create(FileSystem::typeForName(dialogWidget().comboFileSystem().currentText()), -1, -1, -1, "");
+	const FileSystem* fs = FileSystemFactory::create(FileSystem::typeForName(dialogWidget().comboFileSystem().currentText()), -1, -1, -1, QString());
 	dialogWidget().m_EditLabel->setMaxLength(fs->maxLabelLength());
 
 	updateSpinCapacity(partition().length());
@@ -177,7 +179,7 @@ void NewDialog::updateHideAndShow()
 	{
 		dialogWidget().label().setReadOnly(true);
 		dialogWidget().noSetLabel().setVisible(true);
-		dialogWidget().noSetLabel().setFont(KGlobalSettings::smallestReadableFont());
+		dialogWidget().noSetLabel().setFont(QFontDatabase::systemFont(QFontDatabase::SmallestReadableFont));
 
 		QPalette palette = dialogWidget().noSetLabel().palette();
 		QColor f = palette.color(QPalette::Foreground);
