@@ -1,21 +1,19 @@
-/***************************************************************************
- *   Copyright (C) 2008,2009,2010 by Volker Lanz <vl@fidra.de>             *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
- ***************************************************************************/
+/*************************************************************************
+ *  Copyright (C) 2008-2010 by Volker Lanz <vl@fidra.de>                 *
+ *                                                                       *
+ *  This program is free software; you can redistribute it and/or        *
+ *  modify it under the terms of the GNU General Public License as       *
+ *  published by the Free Software Foundation; either version 3 of       *
+ *  the License, or (at your option) any later version.                  *
+ *                                                                       *
+ *  This program is distributed in the hope that it will be useful,      *
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of       *
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
+ *  GNU General Public License for more details.                         *
+ *                                                                       *
+ *  You should have received a copy of the GNU General Public License    *
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
+ *************************************************************************/
 
 #if !defined(PARTITIONMANAGERWIDGET__H)
 
@@ -51,13 +49,13 @@ class LIBPARTITIONMANAGERPRIVATE_EXPORT PartitionManagerWidget : public QWidget,
 		PartitionManagerWidget(QWidget* parent = NULL);
 		virtual ~PartitionManagerWidget();
 
-	signals:
+	Q_SIGNALS:
 		void selectedPartitionChanged(const Partition*);
 		void contextMenuRequested(const QPoint&);
 		void deviceDoubleClicked(const Device*);
 		void partitionDoubleClicked(const Partition* p);
 
-	public slots:
+	public Q_SLOTS:
 		void setSelectedDevice(Device* d);
 		void setSelectedDevice(const QString& device_node);
 
@@ -111,7 +109,7 @@ class LIBPARTITIONMANAGERPRIVATE_EXPORT PartitionManagerWidget : public QWidget,
 		QTreeWidget& treePartitions() { Q_ASSERT(m_TreePartitions); return *m_TreePartitions; }
 		const QTreeWidget& treePartitions() const { Q_ASSERT(m_TreePartitions); return *m_TreePartitions; }
 
-	protected slots:
+	protected Q_SLOTS:
 		void on_m_TreePartitions_currentItemChanged(QTreeWidgetItem* current, QTreeWidgetItem* previous);
 		void on_m_TreePartitions_customContextMenuRequested(const QPoint& pos);
 		void on_m_TreePartitions_itemDoubleClicked(QTreeWidgetItem* item, int);
