@@ -1,21 +1,19 @@
-/***************************************************************************
- *   Copyright (C) 2008,2009 by Volker Lanz <vl@fidra.de>                  *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
- ***************************************************************************/
+/*************************************************************************
+ *  Copyright (C) 2008, 2009 by Volker Lanz <vl@fidra.de>                *
+ *                                                                       *
+ *  This program is free software; you can redistribute it and/or        *
+ *  modify it under the terms of the GNU General Public License as       *
+ *  published by the Free Software Foundation; either version 3 of       *
+ *  the License, or (at your option) any later version.                  *
+ *                                                                       *
+ *  This program is distributed in the hope that it will be useful,      *
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of       *
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
+ *  GNU General Public License for more details.                         *
+ *                                                                       *
+ *  You should have received a copy of the GNU General Public License    *
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
+ *************************************************************************/
 
 #include "gui/partpropsdialog.h"
 #include "gui/partpropswidget.h"
@@ -28,21 +26,25 @@
 #include "util/capacity.h"
 #include "util/helpers.h"
 
-#include <kmessagebox.h>
-#include <kdebug.h>
-#include <kglobalsettings.h>
-#include <kpushbutton.h>
-#include <klineedit.h>
-
+#include <QComboBox>
+#include <QFontDatabase>
+#include <QLineEdit>
+#include <QLocale>
+#include <QPushButton>
 #include <QtAlgorithms>
 
+#include <KConfigGroup>
+#include <KLocalizedString>
+#include <KMessageBox>
+#include <KSharedConfig>
+
 /** Creates a new PartPropsDialog
 	@param parent pointer to the parent widget
 	@param d the Device the Partition is on
 	@param p the Partition to show properties for
 */
 PartPropsDialog::PartPropsDialog(QWidget* parent, Device& d, Partition& p) :
-	KDialog(parent),
+	QDialog(parent),
 	m_Device(d),
 	m_Partition(p),
 	m_WarnFileSystemChange(false),
@@ -50,20 +52,24 @@ PartPropsDialog::PartPropsDialog(QWidget* parent, Device& d, Partition& p) :
 	m_ReadOnly(partition().isMounted() || partition().state() == Partition::StateCopy || partition().state() == Partition::StateRestore || d.partitionTable()->isReadOnly()),
 	m_ForceRecreate(false)
 {
-	setMainWidget(&dialogWidget());
-	setCaption(i18nc("@title:window", "Partition properties: <filename>%1</filename>", partition().deviceNode()));
+	mainLayout = new QVBoxLayout(this);
+	setLayout(mainLayout);
+	mainLayout->addWidget(&dialogWidget());
+
+	setWindowTitle(xi18nc("@title:window", "Partition properties: <filename>%1</filename>", partition().deviceNode()));
 
 	setupDialog();
 	setupConnections();
 
-	restoreDialogSize(KConfigGroup(KGlobal::config(), "partPropsDialog"));
+	KConfigGroup kcg(KSharedConfig::openConfig(), "partPropsDialog");
+	restoreGeometry(kcg.readEntry<QByteArray>("Geometry", QByteArray()));
 }
 
 /** Destroys a PartPropsDialog */
 PartPropsDialog::~PartPropsDialog()
 {
-	KConfigGroup kcg(KGlobal::config(), "partPropsDialog");
-	saveDialogSize(kcg);
+	KConfigGroup kcg(KSharedConfig::openConfig(), "partPropsDialog");
+	kcg.writeEntry("Geometry", saveGeometry());
 }
 
 /** @return the new label */
@@ -92,9 +98,15 @@ FileSystem::Type PartPropsDialog::newFileSystemType() const
 
 void PartPropsDialog::setupDialog()
 {
-	setDefaultButton(KDialog::Cancel);
-	enableButtonOk(false);
-	button(KDialog::Cancel)->setFocus();
+	dialogButtonBox = new QDialogButtonBox;
+	okButton = dialogButtonBox->addButton( QDialogButtonBox::Ok );
+	cancelButton = dialogButtonBox->addButton( QDialogButtonBox::Cancel );
+	mainLayout->addWidget(dialogButtonBox);
+	okButton->setEnabled(false);
+	cancelButton->setFocus();
+	cancelButton->setDefault(true);
+	connect(dialogButtonBox, SIGNAL(accepted()), this, SLOT(accept()));
+	connect(dialogButtonBox, SIGNAL(rejected()), this, SLOT(reject()));
 
 	dialogWidget().partWidget().init(&partition());
 
@@ -111,7 +123,7 @@ void PartPropsDialog::setupDialog()
 		if (partition().roles().has(PartitionRole::Extended))
 			statusText = i18nc("@label partition state", "At least one logical partition is mounted.");
 		else if (!partition().mountPoint().isEmpty())
-			statusText = i18nc("@label partition state", "mounted on <filename>%1</filename>", mp);
+			statusText = xi18nc("@label partition state", "mounted on <filename>%1</filename>", mp);
 		else
 			statusText = i18nc("@label partition state", "mounted");
 	}
@@ -129,10 +141,10 @@ void PartPropsDialog::setupDialog()
 	{
 		const qint64 availPercent = (partition().fileSystem().length() - partition().fileSystem().sectorsUsed()) * 100 / partition().fileSystem().length();
 
-		const QString availString = QString("%1% - %2")
+		const QString availString = QStringLiteral("%1% - %2")
 			.arg(availPercent)
 			.arg(Capacity::formatByteSize(partition().available()));
-		const QString usedString = QString("%1% - %2")
+		const QString usedString = QStringLiteral("%1% - %2")
 			.arg(100 - availPercent)
 			.arg(Capacity::formatByteSize(partition().used()));
 
@@ -145,9 +157,9 @@ void PartPropsDialog::setupDialog()
 		dialogWidget().used().setText(Capacity::invalidString());
 	}
 
-	dialogWidget().firstSector().setText(KGlobal::locale()->formatNumber(partition().firstSector(), 0));
-	dialogWidget().lastSector().setText(KGlobal::locale()->formatNumber(partition().lastSector(), 0));
-	dialogWidget().numSectors().setText(KGlobal::locale()->formatNumber(partition().length(), 0));
+	dialogWidget().firstSector().setText(QLocale().toString(partition().firstSector()));
+	dialogWidget().lastSector().setText(QLocale().toString(partition().lastSector()));
+	dialogWidget().numSectors().setText(QLocale().toString(partition().length()));
 
 	setupFlagsList();
 
@@ -179,13 +191,13 @@ void PartPropsDialog::setupFlagsList()
 void PartPropsDialog::updateHideAndShow()
 {
 	// create a temporary fs for some checks
-	const FileSystem* fs = FileSystemFactory::create(newFileSystemType(), -1, -1, -1, "");
+	const FileSystem* fs = FileSystemFactory::create(newFileSystemType(), -1, -1, -1, QString());
 
 	if (fs == NULL || fs->supportSetLabel() == FileSystem::cmdSupportNone)
 	{
 		dialogWidget().label().setReadOnly(true);
 		dialogWidget().noSetLabel().setVisible(true);
-		dialogWidget().noSetLabel().setFont(KGlobalSettings::smallestReadableFont());
+		dialogWidget().noSetLabel().setFont(QFontDatabase::systemFont(QFontDatabase::SmallestReadableFont));
 
 		QPalette palette = dialogWidget().noSetLabel().palette();
 		QColor f = palette.color(QPalette::Foreground);
@@ -264,8 +276,8 @@ void PartPropsDialog::setupConnections()
 
 void PartPropsDialog::setDirty()
 {
-	setDefaultButton(KDialog::Ok);
-	enableButtonOk(true);
+	okButton->setEnabled(true);
+	okButton->setDefault(true);
 }
 
 void PartPropsDialog::setupFileSystemComboBox()
@@ -309,7 +321,7 @@ void PartPropsDialog::setupFileSystemComboBox()
 
 	dialogWidget().fileSystem().setCurrentIndex(dialogWidget().fileSystem().findText(selected));
 
-	const FileSystem* fs = FileSystemFactory::create(FileSystem::typeForName(dialogWidget().fileSystem().currentText()), -1, -1, -1, "");
+	const FileSystem* fs = FileSystemFactory::create(FileSystem::typeForName(dialogWidget().fileSystem().currentText()), -1, -1, -1, QString());
 	dialogWidget().m_EditLabel->setMaxLength(fs->maxLabelLength());
 }
 
@@ -324,18 +336,18 @@ void PartPropsDialog::updatePartitionFileSystem()
 void PartPropsDialog::onFilesystemChanged(int)
 {
 	if (partition().state() == Partition::StateNew || warnFileSystemChange() || KMessageBox::warningContinueCancel(this,
-			i18nc("@info", "<para><warning>You are about to lose all data on partition <filename>%1</filename>.</warning></para>"
+			xi18nc("@info", "<para><warning>You are about to lose all data on partition <filename>%1</filename>.</warning></para>"
 				"<para>Changing the file system on a partition already on disk will erase all its contents. If you continue now and apply the resulting operation in the main window, all data on <filename>%1</filename> will unrecoverably be lost.</para>", partition().deviceNode()),
-			i18nc("@title:window", "Really Recreate <filename>%1</filename> with File System %2?", partition().deviceNode(), dialogWidget().fileSystem().currentText()),
-			KGuiItem(i18nc("@action:button", "Change the File System"), "arrow-right"),
-			KGuiItem(i18nc("@action:button", "Do Not Change the File System"), "dialog-cancel"), "reallyChangeFileSystem") == KMessageBox::Continue)
+			xi18nc("@title:window", "Really Recreate <filename>%1</filename> with File System %2?", partition().deviceNode(), dialogWidget().fileSystem().currentText()),
+			KGuiItem(i18nc("@action:button", "Change the File System"), QStringLiteral("arrow-right")),
+			KGuiItem(i18nc("@action:button", "Do Not Change the File System"), QStringLiteral("dialog-cancel")), QStringLiteral("reallyChangeFileSystem")) == KMessageBox::Continue)
 	{
 		setDirty();
 		updateHideAndShow();
 		setWarnFileSystemChange();
 		updatePartitionFileSystem();
 
-		const FileSystem* fs = FileSystemFactory::create(FileSystem::typeForName(dialogWidget().fileSystem().currentText()), -1, -1, -1, "");
+		const FileSystem* fs = FileSystemFactory::create(FileSystem::typeForName(dialogWidget().fileSystem().currentText()), -1, -1, -1, QString());
 		dialogWidget().m_EditLabel->setMaxLength(fs->maxLabelLength());
 	}
 	else
@@ -349,11 +361,11 @@ void PartPropsDialog::onFilesystemChanged(int)
 void PartPropsDialog::onRecreate(int state)
 {
 	if (state == Qt::Checked && (warnFileSystemChange() || KMessageBox::warningContinueCancel(this,
-			i18nc("@info", "<para><warning>You are about to lose all data on partition <filename>%1</filename>.</warning></para>"
-				"<para>Recreating a file system will erase all its contents. If you continue now and apply the resulting operation in the main window, all data on <filename>%1</filename> will unrecoverably be lost.</para>", partition().deviceNode()),
-			i18nc("@title:window", "Really Recreate File System on <filename>%1</filename>?", partition().deviceNode()),
-			KGuiItem(i18nc("@action:button", "Recreate the File System"), "arrow-right"),
-			KGuiItem(i18nc("@action:button", "Do Not Recreate the File System"), "dialog-cancel"), "reallyRecreateFileSystem") == KMessageBox::Continue))
+			xi18nc("@info", "<para><warning>You are about to lose all data on partition <filename>%1</filename>.</warning></para>"
+				"<para>Recreating a file system will erase all its contents. If you continue now and apply the resulting operation in the main window, all data on <filesystem>%1</filesystem> will unrecoverably be lost.</para>", partition().deviceNode()),
+			xi18nc("@title:window", "Really Recreate File System on <filename>%1</filename>?", partition().deviceNode()),
+			KGuiItem(i18nc("@action:button", "Recreate the File System"), QStringLiteral("arrow-right")),
+			KGuiItem(i18nc("@action:button", "Do Not Recreate the File System"), QStringLiteral("dialog-cancel")), QStringLiteral("reallyRecreateFileSystem")) == KMessageBox::Continue))
 	{
 		setDirty();
 		setWarnFileSystemChange();
