@@ -1,21 +1,19 @@
-/***************************************************************************
- *   Copyright (C) 2008 by Volker Lanz <vl@fidra.de>                       *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
- ***************************************************************************/
+/*************************************************************************
+ *  Copyright (C) 2008 by Volker Lanz <vl@fidra.de>                      *
+ *                                                                       *
+ *  This program is free software; you can redistribute it and/or        *
+ *  modify it under the terms of the GNU General Public License as       *
+ *  published by the Free Software Foundation; either version 3 of       *
+ *  the License, or (at your option) any later version.                  *
+ *                                                                       *
+ *  This program is distributed in the hope that it will be useful,      *
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of       *
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
+ *  GNU General Public License for more details.                         *
+ *                                                                       *
+ *  You should have received a copy of the GNU General Public License    *
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
+ *************************************************************************/
 
 #if !defined(PARTPROPSDIALOG__H)
 
@@ -26,11 +24,13 @@
 #include "core/partition.h"
 #include "core/partitiontable.h"
 
-#include <kdialog.h>
+#include <QDialog>
 
 class Device;
 class PartPropsWidget;
 
+class QDialogButtonBox;
+class QVBoxLayout;
 class QWidget;
 class QString;
 
@@ -42,7 +42,7 @@ class QString;
 
 	@author Volker Lanz <vl@fidra.de>
 */
-class PartPropsDialog : public KDialog
+class PartPropsDialog : public QDialog
 {
 	Q_OBJECT
 	Q_DISABLE_COPY(PartPropsDialog)
@@ -81,7 +81,7 @@ class PartPropsDialog : public KDialog
 
 		void updatePartitionFileSystem();
 
-	protected slots:
+	protected Q_SLOTS:
 		void setDirty();
 		void onFilesystemChanged(int idx);
 		void onRecreate(int);
@@ -99,6 +99,12 @@ class PartPropsDialog : public KDialog
 		PartPropsWidget* m_DialogWidget;
 		bool m_ReadOnly;
 		bool m_ForceRecreate;
+
+		QDialogButtonBox* dialogButtonBox;
+		QPushButton* okButton;
+		QPushButton* cancelButton;
+		QVBoxLayout *mainLayout;
+
 };
 
 #endif
