@@ -1,21 +1,19 @@
-/***************************************************************************
- *   Copyright (C) 2008,2010 by Volker Lanz <vl@fidra.de>                  *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
- ***************************************************************************/
+/*************************************************************************
+ *  Copyright (C) 2008, 2010 by Volker Lanz <vl@fidra.de>                *
+ *                                                                       *
+ *  This program is free software; you can redistribute it and/or        *
+ *  modify it under the terms of the GNU General Public License as       *
+ *  published by the Free Software Foundation; either version 3 of       *
+ *  the License, or (at your option) any later version.                  *
+ *                                                                       *
+ *  This program is distributed in the hope that it will be useful,      *
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of       *
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
+ *  GNU General Public License for more details.                         *
+ *                                                                       *
+ *  You should have received a copy of the GNU General Public License    *
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
+ *************************************************************************/
 
 #include "gui/resizedialog.h"
 #include "gui/sizedialogwidget.h"
@@ -29,7 +27,9 @@
 
 #include "util/capacity.h"
 
-#include <kdebug.h>
+#include <KConfigGroup>
+#include <KLocalizedString>
+#include <KSharedConfig>
 
 /** Creates a new ResizeDialog
 	@param parent pointer to the parent widget
@@ -45,7 +45,7 @@ ResizeDialog::ResizeDialog(QWidget* parent, Device& d, Partition& p, qint64 minF
 	m_ResizedFirstSector(p.firstSector()),
 	m_ResizedLastSector(p.lastSector())
 {
-	setCaption(i18nc("@title:window", "Resize/move partition: <filename>%1</filename>", partition().deviceNode()));
+	setWindowTitle(xi18nc("@title:window", "Resize/move partition: <filename>%1</filename>", partition().deviceNode()));
 
 	dialogWidget().hideRole();
 	dialogWidget().hideFileSystem();
@@ -55,14 +55,15 @@ ResizeDialog::ResizeDialog(QWidget* parent, Device& d, Partition& p, qint64 minF
 	setupConstraints();
 	setupConnections();
 
-	restoreDialogSize(KConfigGroup(KGlobal::config(), "resizeDialog"));
+	KConfigGroup kcg(KSharedConfig::openConfig(), "resizeDialog");
+	restoreGeometry(kcg.readEntry<QByteArray>("Geometry", QByteArray()));
 }
 
 /** Destroys a ResizeDialog */
 ResizeDialog::~ResizeDialog()
 {
-	KConfigGroup kcg(KGlobal::config(), "resizeDialog");
-	saveDialogSize(kcg);
+	KConfigGroup kcg(KSharedConfig::openConfig(), "resizeDialog");
+	kcg.writeEntry("Geometry", saveGeometry());
 }
 
 void ResizeDialog::rollback()
@@ -86,24 +87,24 @@ void ResizeDialog::accept()
 	setResizedLastSector(partition().lastSector());
 
 	rollback();
-	KDialog::accept();
+	QDialog::accept();
 }
 
 void ResizeDialog::reject()
 {
 	rollback();
-	KDialog::reject();
+	QDialog::reject();
 }
 
 void ResizeDialog::setupDialog()
 {
 	SizeDialogBase::setupDialog();
-	enableButtonOk(false);
+	okButton->setEnabled(false);
 }
 
 void ResizeDialog::setDirty()
 {
-	enableButtonOk(isModified());
+	okButton->setEnabled(isModified());
 }
 
 /** @return true if the user modified anything */
