@@ -1,22 +1,19 @@
-/***************************************************************************
- *   Copyright (C) 2008,2010 by Volker Lanz <vl@fidra.de>                  *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
- ***************************************************************************/
-
+/*************************************************************************
+ *  Copyright (C) 2008, 2010 by Volker Lanz <vl@fidra.de>                *
+ *                                                                       *
+ *  This program is free software; you can redistribute it and/or        *
+ *  modify it under the terms of the GNU General Public License as       *
+ *  published by the Free Software Foundation; either version 3 of       *
+ *  the License, or (at your option) any later version.                  *
+ *                                                                       *
+ *  This program is distributed in the hope that it will be useful,      *
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of       *
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
+ *  GNU General Public License for more details.                         *
+ *                                                                       *
+ *  You should have received a copy of the GNU General Public License    *
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
+ *************************************************************************/
 #if !defined(SIZEDIALOGBASE__H)
 
 #define SIZEDIALOGBASE__H
@@ -24,9 +21,9 @@
 #include "util/capacity.h"
 
 #include <qglobal.h>
-#include <qdebug.h>
-
-#include <kdialog.h>
+#include <QDebug>
+#include <QDialog>
+#include <QPushButton>
 
 class Device;
 class Partition;
@@ -37,7 +34,7 @@ class SizeDetailsWidget;
 /** Base class for all dialogs moving or resizing Partitions.
 	@author Volker Lanz <vl@fidra.de>
 */
-class SizeDialogBase : public KDialog
+class SizeDialogBase : public QDialog
 {
 	Q_OBJECT
 	Q_DISABLE_COPY(SizeDialogBase)
@@ -83,7 +80,7 @@ class SizeDialogBase : public KDialog
 		virtual void setMinimumLength(qint64 s) { m_MinimumLength = s; }
 		virtual void setMaximumLength(qint64 s) { m_MaximumLength = s; }
 
-	protected slots:
+	protected Q_SLOTS:
 		void onResizerWidgetFirstSectorChanged(qint64 newFirst);
 		void onResizerWidgetLastSectorChanged(qint64 newLast);
 
@@ -95,6 +92,8 @@ class SizeDialogBase : public KDialog
 		void onSpinLastSectorChanged(double newLast);
 		void onAlignToggled(bool);
 
+		void toggleDetails();
+
 	protected:
 		SizeDialogWidget* m_SizeDialogWidget;
 		SizeDetailsWidget* m_SizeDetailsWidget;
@@ -104,6 +103,11 @@ class SizeDialogBase : public KDialog
 		qint64 m_MaximumLastSector;
 		qint64 m_MinimumLength;
 		qint64 m_MaximumLength;
+
+	public:
+		QPushButton* okButton;
+		QPushButton* cancelButton;
+		QPushButton* detailsButton;
 };
 
 #endif
