@@ -1,21 +1,19 @@
-/***************************************************************************
- *   Copyright (C) 2008,2009 by Volker Lanz <vl@fidra.de>                  *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
- ***************************************************************************/
+/*************************************************************************
+ *  Copyright (C) 2008, 2009 by Volker Lanz <vl@fidra.de>                *
+ *                                                                       *
+ *  This program is free software; you can redistribute it and/or        *
+ *  modify it under the terms of the GNU General Public License as       *
+ *  published by the Free Software Foundation; either version 3 of       *
+ *  the License, or (at your option) any later version.                  *
+ *                                                                       *
+ *  This program is distributed in the hope that it will be useful,      *
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of       *
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
+ *  GNU General Public License for more details.                         *
+ *                                                                       *
+ *  You should have received a copy of the GNU General Public License    *
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
+ *************************************************************************/
 
 #include "gui/treelog.h"
 
@@ -24,22 +22,21 @@
 #include "util/globallog.h"
 #include "util/helpers.h"
 
-#include <kactioncollection.h>
-#include <kdebug.h>
-#include <kiconloader.h>
-#include <kfiledialog.h>
-#include <kmessagebox.h>
-#include <kstandardguiitem.h>
-#include <kio/netaccess.h>
-#include <kio/jobuidelegate.h>
-#include <kio/copyjob.h>
-#include <ktemporaryfile.h>
-
+#include <QDateTime>
+#include <QDebug>
 #include <QFile>
+#include <QFileDialog>
+#include <QMenu>
+#include <QTemporaryFile>
+#include <QTextStream>
 #include <QTreeWidget>
 #include <QTreeWidgetItem>
-#include <QDateTime>
-#include <QTextStream>
+
+#include <KIconThemes/KIconLoader>
+#include <KIO/CopyJob>
+#include <KJobUiDelegate>
+#include <KLocalizedString>
+#include <KMessageBox>
 
 #include <config.h>
 
@@ -104,7 +101,7 @@ void TreeLog::saveConfig() const
 	Config::setTreeLogColumnVisible(colVisible);
 	Config::setTreeLogColumnWidths(colWidths);
 
-	Config::self()->writeConfig();
+	Config::self()->save();
 }
 
 void TreeLog::onHeaderContextMenu(const QPoint& pos)
@@ -120,15 +117,15 @@ void TreeLog::onClearLog()
 
 void TreeLog::onSaveLog()
 {
-	const KUrl url = KFileDialog::getSaveUrl(KUrl("kfiledialog://saveLog"));
+	const QUrl url = QFileDialog::getSaveFileUrl();
 
 	if (!url.isEmpty())
 	{
-		KTemporaryFile tempFile;
+		QTemporaryFile tempFile;
 
 		if (!tempFile.open())
 		{
-			KMessageBox::error(this, i18nc("@info", "Could not create temporary output file to save <filename>%1</filename>.", url.fileName()), i18nc("@title:window", "Error Saving Log File"));
+			KMessageBox::error(this, xi18nc("@info", "Could not create temporary output file to save <filename>%1</filename>.", url.fileName()), i18nc("@title:window", "Error Saving Log File"));
 			return;
 		}
 
@@ -142,8 +139,9 @@ void TreeLog::onSaveLog()
 
 		tempFile.close();
 
-		KIO::CopyJob* job = KIO::move(tempFile.fileName(), url, KIO::HideProgressInfo);
-		if (!KIO::NetAccess::synchronousRun(job, NULL))
+		KIO::CopyJob* job = KIO::move(QUrl::fromLocalFile(tempFile.fileName()), url, KIO::HideProgressInfo);
+		job->exec();
+		if ( job->error() )
 			job->ui()->showErrorMessage();
 	}
 }
@@ -155,22 +153,22 @@ void TreeLog::on_m_TreeLog_customContextMenuRequested(const QPoint& pos)
 
 void TreeLog::onNewLogMessage(Log::Level logLevel, const QString& s)
 {
-	static const char* icons[] =
+	static const QString icons[] =
 	{
-		"tools-report-bug",
-		"dialog-information",
-		"dialog-warning",
-		"dialog-error"
+		QStringLiteral("tools-report-bug"),
+		QStringLiteral("dialog-information"),
+		QStringLiteral("dialog-warning"),
+		QStringLiteral("dialog-error")
 	};
 
-	kDebug() << s;
+	qDebug() << s;
 
 	if (logLevel >= Config::minLogLevel())
 	{
 		QTreeWidgetItem* item = new QTreeWidgetItem();
 
-		item->setIcon(0, SmallIcon(icons[logLevel]));
-		item->setText(1, QDateTime::currentDateTime().toString("yyyy-MM-dd hh:mm:ss"));
+		item->setIcon(0, QIcon(KIconLoader().loadIcon(icons[logLevel], KIconLoader::Small)));
+		item->setText(1, QDateTime::currentDateTime().toString(QStringLiteral("yyyy-MM-dd hh:mm:ss")));
 		item->setText(2, s);
 
 		treeLog().addTopLevelItem(item);
