@@ -1,21 +1,19 @@
-/***************************************************************************
- *   Copyright (C) 2008,2009,2010,2011,2012 by Volker Lanz <vl@fidra.de>   *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
- ***************************************************************************/
+/*************************************************************************
+ *  Copyright (C) 2008-2012 by Volker Lanz <vl@fidra.de>                 *
+ *                                                                       *
+ *  This program is free software; you can redistribute it and/or        *
+ *  modify it under the terms of the GNU General Public License as       *
+ *  published by the Free Software Foundation; either version 3 of       *
+ *  the License, or (at your option) any later version.                  *
+ *                                                                       *
+ *  This program is distributed in the hope that it will be useful,      *
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of       *
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
+ *  GNU General Public License for more details.                         *
+ *                                                                       *
+ *  You should have received a copy of the GNU General Public License    *
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
+ *************************************************************************/
 
 /** @file
 */
@@ -41,38 +39,18 @@
 
 #include <QString>
 #include <QStringList>
+#include <QDebug>
 
-#include <kdebug.h>
-#include <klocale.h>
-#include <kmountpoint.h>
-#include <kdiskfreespaceinfo.h>
-#include <kpluginfactory.h>
-#include <kaboutdata.h>
+#include <KLocalizedString>
+#include <KIOCore/KMountPoint>
+#include <KIOCore/KDiskFreeSpaceInfo>
+#include <KPluginFactory>
 
 #include <parted/parted.h>
 #include <unistd.h>
 #include <blkid/blkid.h>
 
-K_PLUGIN_FACTORY(LibPartedBackendFactory, registerPlugin<LibPartedBackend>(); )
-
-static KAboutData createPluginAboutData()
-{
-	KAboutData about(
-		"pmlibpartedbackendplugin",
-		NULL,
-		ki18nc("@title", "LibParted Backend Plugin"),
-		QString("%1, libparted version: %2").arg(VERSION).arg(ped_get_version()).toUtf8(),
-		ki18n("KDE Partition Manager backend for libparted."),
-		KAboutData::License_GPL,
-		ki18n("Copyright 2008,2009,2010 Volker Lanz"));
-
-	about.addAuthor(ki18nc("@info:credit", "Volker Lanz"));
-	about.setHomepage("http://www.partitionmanager.org");
-
-	return about;
-}
-
-K_EXPORT_PLUGIN(LibPartedBackendFactory(createPluginAboutData()))
+K_PLUGIN_FACTORY_WITH_JSON(LibPartedBackendFactory, "pmlibpartedbackendplugin.json", registerPlugin<LibPartedBackend>();)
 
 static struct
 {
@@ -93,13 +71,15 @@ static struct
 	{ PED_PARTITION_MSFT_RESERVED, PartitionTable::FlagMsftReserved }
 };
 
+static QString s_lastPartedExceptionMessage;
+
 /** Callback to handle exceptions from libparted
 	@param e the libparted exception to handle
 */
 static PedExceptionOption pedExceptionHandler(PedException* e)
 {
-	/** @todo These messages should end up in the Report, not in the GlobalLog. */
 	Log(Log::error) << i18nc("@info/plain", "LibParted Exception: %1", QString::fromLocal8Bit(e->message));
+	s_lastPartedExceptionMessage = QString::fromLocal8Bit(e->message);
 	return PED_EXCEPTION_UNHANDLED;
 }
 
@@ -138,7 +118,7 @@ typedef struct _GPTDiskData GPTDiskData;
 */
 static quint64 firstUsableSector(const Device& d)
 {
-	PedDevice* pedDevice = ped_device_get(d.deviceNode().toAscii());
+	PedDevice* pedDevice = ped_device_get(d.deviceNode().toLatin1().constData());
 	PedDisk* pedDisk = pedDevice ? ped_disk_new(pedDevice) : NULL;
 
 	quint64 rval = pedDisk->dev->bios_geom.sectors;
@@ -163,7 +143,7 @@ static quint64 firstUsableSector(const Device& d)
 */
 static quint64 lastUsableSector(const Device& d)
 {
-	PedDevice* pedDevice = ped_device_get(d.deviceNode().toAscii());
+	PedDevice* pedDevice = ped_device_get(d.deviceNode().toLatin1().constData());
 	PedDisk* pedDisk = pedDevice ? ped_disk_new(pedDevice) : NULL;
 
 	quint64 rval = pedDisk->dev->bios_geom.sectors * pedDisk->dev->bios_geom.heads * pedDisk->dev->bios_geom.cylinders - 1;
@@ -362,7 +342,7 @@ void LibPartedBackend::scanDevicePartitions(PedDevice*, Device& d, PedDisk* pedD
 		if (parent == NULL)
 			parent = d.partitionTable();
 
-		const QString node = QString(ped_partition_get_path(pedPartition));
+		const QString node = QString::fromUtf8(ped_partition_get_path(pedPartition));
 		FileSystem* fs = FileSystemFactory::create(type, pedPartition->geom.start, pedPartition->geom.end);
 
 		// libparted does not handle LUKS partitions
@@ -371,7 +351,7 @@ void LibPartedBackend::scanDevicePartitions(PedDevice*, Device& d, PedDisk* pedD
 		if (fs->type() == FileSystem::Luks)
 		{
 			mountPoint = FS::luks::mapperName(node);
-			mounted = (mountPoint != "") ? true : false;
+			mounted = (mountPoint != QString()) ? true : false;
 		}
 		else
 		{
@@ -410,23 +390,23 @@ void LibPartedBackend::scanDevicePartitions(PedDevice*, Device& d, PedDisk* pedD
 */
 Device* LibPartedBackend::scanDevice(const QString& device_node)
 {
-	PedDevice* pedDevice = ped_device_get(device_node.toLocal8Bit());
+	PedDevice* pedDevice = ped_device_get(device_node.toLocal8Bit().constData());
 
 	if (pedDevice == NULL)
 	{
-		Log(Log::warning) << i18nc("@info/plain", "Could not access device <filename>%1</filename>", device_node);
+		Log(Log::warning) << xi18nc("@info/plain", "Could not access device <filename>%1</filename>", device_node);
 		return NULL;
 	}
 
-	Log(Log::information) << i18nc("@info/plain", "Device found: %1", pedDevice->model);
+	Log(Log::information) << i18nc("@info/plain", "Device found: %1", QString::fromUtf8(pedDevice->model));
 
-	Device* d = new Device(pedDevice->model, pedDevice->path, pedDevice->bios_geom.heads, pedDevice->bios_geom.sectors, pedDevice->bios_geom.cylinders, pedDevice->sector_size);
+	Device* d = new Device(QString::fromUtf8(pedDevice->model), QString::fromUtf8(pedDevice->path), pedDevice->bios_geom.heads, pedDevice->bios_geom.sectors, pedDevice->bios_geom.cylinders, pedDevice->sector_size);
 
 	PedDisk* pedDisk = ped_disk_new(pedDevice);
 
 	if (pedDisk)
 	{
-		const PartitionTable::TableType type = PartitionTable::nameToTableType(pedDisk->type->name);
+		const PartitionTable::TableType type = PartitionTable::nameToTableType(QString::fromUtf8(pedDisk->type->name));
 		CoreBackend::setPartitionTableForDevice(*d, new PartitionTable(type, firstUsableSector(*d), lastUsableSector(*d)));
 		CoreBackend::setPartitionTableMaxPrimaries(*d->partitionTable(), ped_disk_get_max_primary_partition_count(pedDisk));
 
@@ -514,23 +494,21 @@ FileSystem::Type LibPartedBackend::detectFileSystem(PedPartition* pedPartition)
 
 		if ((dev = blkid_get_dev(cache, pedPath, BLKID_DEV_NORMAL)) != NULL)
 		{
-			char* tmp = blkid_get_tag_value(cache, "TYPE", pedPath);
-			const QString s(tmp);
-			free(tmp);
+			QString s = QString::fromUtf8(blkid_get_tag_value(cache, "TYPE", pedPath));
 
-			if (s == "ext2") rval = FileSystem::Ext2;
-			else if (s == "ext3") rval = FileSystem::Ext3;
-			else if (s.startsWith("ext4")) rval = FileSystem::Ext4;
-			else if (s == "swap") rval = FileSystem::LinuxSwap;
-			else if (s == "ntfs") rval = FileSystem::Ntfs;
-			else if (s == "reiserfs") rval = FileSystem::ReiserFS;
-			else if (s == "reiser4") rval = FileSystem::Reiser4;
-			else if (s == "xfs") rval = FileSystem::Xfs;
-			else if (s == "jfs") rval = FileSystem::Jfs;
-			else if (s == "hfs") rval = FileSystem::Hfs;
-			else if (s == "hfsplus") rval = FileSystem::HfsPlus;
-			else if (s == "ufs") rval = FileSystem::Ufs;
-			else if (s == "vfat" && pedPartition->fs_type != NULL)
+			if (s == QStringLiteral("ext2")) rval = FileSystem::Ext2;
+			else if (s == QStringLiteral("ext3")) rval = FileSystem::Ext3;
+			else if (s.startsWith(QStringLiteral("ext4"))) rval = FileSystem::Ext4;
+			else if (s == QStringLiteral("swap")) rval = FileSystem::LinuxSwap;
+			else if (s == QStringLiteral("ntfs")) rval = FileSystem::Ntfs;
+			else if (s == QStringLiteral("reiserfs")) rval = FileSystem::ReiserFS;
+			else if (s == QStringLiteral("reiser4")) rval = FileSystem::Reiser4;
+			else if (s == QStringLiteral("xfs")) rval = FileSystem::Xfs;
+			else if (s == QStringLiteral("jfs")) rval = FileSystem::Jfs;
+			else if (s == QStringLiteral("hfs")) rval = FileSystem::Hfs;
+			else if (s == QStringLiteral("hfsplus")) rval = FileSystem::HfsPlus;
+			else if (s == QStringLiteral("ufs")) rval = FileSystem::Ufs;
+			else if (s == QStringLiteral("vfat") && pedPartition->fs_type != NULL)
 			{
 				// libblkid does not distinguish between fat16 and fat32, so we're still using libparted
 				// for those
@@ -539,16 +517,16 @@ FileSystem::Type LibPartedBackend::detectFileSystem(PedPartition* pedPartition)
 				else if (strcmp(pedPartition->fs_type->name, "fat32") == 0)
 					rval = FileSystem::Fat32;
 			}
-			else if (s == "btrfs") rval = FileSystem::Btrfs;
-			else if (s == "ocfs2") rval = FileSystem::Ocfs2;
-			else if (s == "zfs_member") rval = FileSystem::Zfs;
-			else if (s == "hpfs") rval = FileSystem::Hpfs;
-			else if (s == "crypto_LUKS") rval = FileSystem::Luks;
-			else if (s == "exfat") rval = FileSystem::Exfat;
-			else if (s == "nilfs2") rval = FileSystem::Nilfs2;
-			else if (s == "LVM2_member") rval = FileSystem::Lvm2_PV;
+			else if (s == QStringLiteral("btrfs")) rval = FileSystem::Btrfs;
+			else if (s == QStringLiteral("ocfs2")) rval = FileSystem::Ocfs2;
+			else if (s == QStringLiteral("zfs_member")) rval = FileSystem::Zfs;
+			else if (s == QStringLiteral("hpfs")) rval = FileSystem::Hpfs;
+			else if (s == QStringLiteral("crypto_LUKS")) rval = FileSystem::Luks;
+			else if (s == QStringLiteral("exfat")) rval = FileSystem::Exfat;
+			else if (s == QStringLiteral("nilfs2")) rval = FileSystem::Nilfs2;
+			else if (s == QStringLiteral("LVM2_member")) rval = FileSystem::Lvm2_PV;
 			else
-				kWarning() << "blkid: unknown file system type " << s << " on " << pedPath;
+				qWarning() << "blkid: unknown file system type " << s << " on " << pedPath;
 		}
 
 		blkid_put_cache(cache);
@@ -568,3 +546,9 @@ PedPartitionFlag LibPartedBackend::getPedFlag(PartitionTable::Flag flag)
 	return static_cast<PedPartitionFlag>(-1);
 }
 
+QString LibPartedBackend::lastPartedExceptionMessage()
+{
+	return s_lastPartedExceptionMessage;
+}
+
+#include "libpartedbackend.moc"
