@@ -1,31 +1,30 @@
-/***************************************************************************
- *   Copyright (C) 2008 by Volker Lanz <vl@fidra.de>                       *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
- ***************************************************************************/
+/*************************************************************************
+ *  Copyright (C) 2008 by Volker Lanz <vl@fidra.de>                      *
+ *                                                                       *
+ *  This program is free software; you can redistribute it and/or        *
+ *  modify it under the terms of the GNU General Public License as       *
+ *  published by the Free Software Foundation; either version 3 of       *
+ *  the License, or (at your option) any later version.                  *
+ *                                                                       *
+ *  This program is distributed in the hope that it will be useful,      *
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of       *
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
+ *  GNU General Public License for more details.                         *
+ *                                                                       *
+ *  You should have received a copy of the GNU General Public License    *
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
+ *************************************************************************/
 
 #include "util/externalcommand.h"
 
 #include "util/report.h"
 
+#include <cstdlib>
+
 #include <QString>
 #include <QStringList>
 
-#include <KLocale>
-#include <KDebug>
+#include <KLocalizedString>
 
 /** Creates a new ExternalCommand instance without Report.
 	@param cmd the command to run
@@ -92,7 +91,7 @@ ExternalCommand::~ExternalCommand()
 
 void ExternalCommand::setup()
 {
-	setEnvironment(QStringList() << "LC_ALL=C" << QString("PATH=") + getenv("PATH"));
+	setEnvironment(QStringList() << QStringLiteral("LC_ALL=C") << QStringLiteral("PATH=") + QString::fromUtf8(getenv("PATH")));
 	setProcessChannelMode(MergedChannels);
 
 	processes = new QProcess[command().size()];
@@ -119,9 +118,9 @@ bool ExternalCommand::start(int timeout)
 		QString s;
 		for (unsigned int i = 0; i < command().size(); i++)
 		{
-			s += command()[i] + " " + args()[i].join(" ");
+			s += command()[i] + QStringLiteral(" ") + args()[i].join(QStringLiteral(" "));
 			if (i < command().size()-1)
-				s += " | ";
+				s += QStringLiteral(" | ");
 		}
 		report()->setCommand(i18nc("@info/plain", "Command: %1", s));
 	}
@@ -131,7 +130,7 @@ bool ExternalCommand::start(int timeout)
 		if (!processes[i].waitForStarted(timeout))
 		{
 			if  (report())
-				report()->line() << i18nc("@info/plain", "(Command timeout while starting \"%1\")", command()[i] + " " + args()[i].join(" "));
+				report()->line() << i18nc("@info/plain", "(Command timeout while starting \"%1\")", command()[i] + QStringLiteral(" ") + args()[i].join(QStringLiteral(" ")));
 
 			return false;
 		}
@@ -153,7 +152,7 @@ bool ExternalCommand::waitFor(int timeout)
 		if (!processes[i].waitForFinished(timeout))
 		{
 			if  (report())
-				report()->line() << i18nc("@info/plain", "(Command timeout while running \"%1\")", command()[i] + " " + args()[i].join(" "));
+				report()->line() << i18nc("@info/plain", "(Command timeout while running \"%1\")", command()[i] + QStringLiteral(" ") + args()[i].join(QStringLiteral(" ")));
 			return false;
 		}
 		onReadOutput();
@@ -172,7 +171,7 @@ bool ExternalCommand::run(int timeout)
 
 void ExternalCommand::onReadOutput()
 {
-	const QString s = QString(processes[command().size()-1].readAllStandardOutput());
+	const QString s = QString::fromUtf8(processes[command().size()-1].readAllStandardOutput());
 
 	m_Output += s;
 
